# Changelog

0.1.2 / 2022-05-23
==================

  * Fix: scope lost in xhr_send and jsonp_send transports after session released.
  * Optimize: heartbeat frame messages do not update session's expires.
  * Optimize: notify frontend when session is to be GC'd.

0.1.1 / 2022-04-09
==================

  * Update version, setup.py and README.md
  * Update tests
  * Update websocket transport
  * Adjust and optimize transports
  * Update examples

0.1.0 / 2022-03-27
==================

  * First implementation steps.
  * Initial commit
